@@ -21,3 +21,10 @@
 }
 
 
+"Para.HOF.list" <-
+    function (resp, ...) 
+{
+    out <- lapply(resp, Para, ...)
+#    class(out) <- "Para.HOF.frame"
+    out
+}
